@@ -150,8 +150,7 @@ class SolarResource(object):
 class DetailedPVModel(object):
     solar_resource: t.Union[t.Tuple[float, float], SolarResource]
     inverter: t.Union[str, Inverter]
-    # TODO: pv module can be detailed
-    pv_module: str
+    pv_module: t.Union[str, PVModule]
     system_design: SystemDesign
     losses: t.Optional[Losses] = opt_field()
     layout: t.Optional[Layout] = opt_field()
@@ -199,10 +198,13 @@ class StorageCoupling(Enum):
     ac = 'ac'
     dc = 'dc'
 
+
+PVModelTypes = t.Union[PVModel, DetailedPVModel]
+
 @dataclass_json
 @dataclass
 class PVStorageModel(object):
     storage_coupling: StorageCoupling = field(metadata=StorageCoupling.__metadata__)
-    pv_inputs: PVModel
+    pv_inputs: PVModelTypes
     storage_inputs: StorageInputs
     energy_prices: t.List[float]
\ No newline at end of file
